@@ -1,7 +1,7 @@
 /*
   scsiadd - add/remove scsi devices from the linux scsi subsystem
   ----------------------------------------------------------------
-  Copyright (C) 2000-2004 by Dirk Jagdmann <doj@cubic.org>
+  Copyright (C) 2000-2005 by Dirk Jagdmann <doj@cubic.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -117,7 +117,7 @@ static int scsiadd(const scsiaddaction_t action,
 		   const int lun)
 {
   char *actionstr, buf[128];
-  int fd, len, ret=0;
+  int fd, len, ret=0, w;
 
   switch(action)
     {
@@ -142,10 +142,17 @@ static int scsiadd(const scsiaddaction_t action,
       return -1;
     }
 
-  if(write(fd, buf, len) != len)
+  errno=0;
+  w=write(fd, buf, len);
+  /* check if the command did not succeed */
+  if(errno && w != len)
     {
-      fprintf(stderr, "could not %s device %i %i %i %i : %s\n", actionstr, host, channel, id, lun, strerror(errno));
-      ret=-1;
+      /* ignore errors in IDs > 8 and EINVAL, which are triggered in scan mode on adapters not support Wide adressing */
+      if(!(id>=9 && errno==EINVAL))
+	{
+	  fprintf(stderr, "could not %s device %i %i %i %i : %s\n", actionstr, host, channel, id, lun, strerror(errno));
+	  ret=-1;
+	}
     }
 
   if(close(fd) < 0)
